==> bulma-extensions-1.0.13.jar: META-INF/resources/webjars/bulma-extensions/1.0.13/bulma-tagsinput/CHANGELOG.md <==
<a name="1.0.1"></a>
## [1.0.1](https://github.com/Wikiki/bulma-tagsinput/compare/1.0.0...1.0.1) (2018-02-11)


### Bug Fixes

* **gulp:** Remove Bulma’s important from dist’sass ([5bb6c9c](https://github.com/Wikiki/bulma-tagsinput/commit/5bb6c9c))



<a name="1.0.0"></a>
# [1.0.0](https://github.com/Wikiki/bulma-tagsinput/compare/0.2.7...1.0.0) (2018-02-10)


### Features

* **rollup:** Add Rollup transpilation ([548c633](https://github.com/Wikiki/bulma-tagsinput/commit/548c633))



<a name="0.2.7"></a>
## [0.2.7](https://github.com/Wikiki/bulma-tagsinput/compare/0.2.6...0.2.7) (2018-02-10)



<a name="0.2.6"></a>
## [0.2.6](https://github.com/Wikiki/bulma-tagsinput/compare/0.2.5...0.2.6) (2018-02-10)


### Bug Fixes

* **gulp:** Use UMD modules style ([3b5c8e6](https://github.com/Wikiki/bulma-tagsinput/commit/3b5c8e6))



<a name="0.2.5"></a>
## [0.2.5](https://github.com/Wikiki/bulma-tagsinput/compare/0.2.4...0.2.5) (2018-02-10)


### Bug Fixes

* **gulp:** Correct dist filenames ([60770e9](https://github.com/Wikiki/bulma-tagsinput/commit/60770e9))
* **package.json:** File paths ([71d2b72](https://github.com/Wikiki/bulma-tagsinput/commit/71d2b72))



<a name="0.2.4"></a>
## [0.2.4](https://github.com/Wikiki/bulma-tagsinput/compare/0.2.3...0.2.4) (2018-02-09)



<a name="0.2.3"></a>
## [0.2.3](https://github.com/Wikiki/bulma-tagsinput/compare/0.1.3...0.2.3) (2018-02-09)


### Bug Fixes

* **bower:** Add missing version ([cbe926e](https://github.com/Wikiki/bulma-tagsinput/commit/cbe926e))


### Features

* **gulp:** Add gulp dependencies ([c2d9f29](https://github.com/Wikiki/bulma-tagsinput/commit/c2d9f29))
* **gulp:** Add release task ([54eb049](https://github.com/Wikiki/bulma-tagsinput/commit/54eb049))



# Change Log

## [Unreleased](https://github.com/wikiki/bulma-tagsinput/tree/HEAD)

[Full Changelog](https://github.com/wikiki/bulma-tagsinput/compare/0.1.3...HEAD)

**Fixed bugs:**

- Tag selection by backspace key for empty input line not working \(Chrome\) [\#11](https://github.com/Wikiki/bulma-tagsinput/issues/11)
- Form field isn't accentuated if focused \(Bulma 0.6.1\) [\#10](https://github.com/Wikiki/bulma-tagsinput/issues/10)
- Selected tag isn't highlighted [\#8](https://github.com/Wikiki/bulma-tagsinput/issues/8)
- Tag selecting of key events is not working properly [\#7](https://github.com/Wikiki/bulma-tagsinput/issues/7)
- Selecting and deleting tags via keys not working in Chrome [\#6](https://github.com/Wikiki/bulma-tagsinput/issues/6)
- doesn't able to delete tag [\#4](https://github.com/Wikiki/bulma-tagsinput/issues/4)
- Can't create a tag with comma [\#3](https://github.com/Wikiki/bulma-tagsinput/issues/3)
- Can't delete tags with backspace key [\#2](https://github.com/Wikiki/bulma-tagsinput/issues/2)
- Update tagsinput.js [\#5](https://github.com/Wikiki/bulma-tagsinput/pull/5) ([nille](https://github.com/nille))

## [0.1.3](https://github.com/wikiki/bulma-tagsinput/tree/0.1.3) (2017-11-30)
**Merged pull requests:**

- Create LICENSE [\#1](https://github.com/Wikiki/bulma-tagsinput/pull/1) ([Wikiki](https://github.com/Wikiki))



\* *This Change Log was automatically generated by [github_changelog_generator](https://github.com/skywinder/Github-Changelog-Generator)*

==> bulma-extensions-6.2.4.jar: META-INF/resources/webjars/bulma-extensions/6.2.4/bulma-tagsinput/CHANGELOG.md <==
<a name="1.0.11"></a>
## [1.0.11](https://github.com/Wikiki/bulma-tagsinput/compare/1.0.9...1.0.11) (2018-05-31)


### Bug Fixes

* options on attach method ([942d936](https://github.com/Wikiki/bulma-tagsinput/commit/942d936))



<a name="1.0.10"></a>
## [1.0.10](https://github.com/Wikiki/bulma-tagsinput/compare/1.0.9...1.0.10) (2018-05-31)


### Bug Fixes

* options on attach method ([942d936](https://github.com/Wikiki/bulma-tagsinput/commit/942d936))



<a name="1.0.9"></a>
## [1.0.9](https://github.com/Wikiki/bulma-tagsinput/compare/1.0.8...1.0.9) (2018-05-31)


### Bug Fixes

* issue [#49](https://github.com/Wikiki/bulma-tagsinput/issues/49) Potential Bug: TagsInput allows duplicate entries ([d88971a](https://github.com/Wikiki/bulma-tagsinput/commit/d88971a))



<a name="1.0.5"></a>
## [1.0.5](https://github.com/Wikiki/bulma-tagsinput/compare/1.0.4...1.0.5) (2018-02-21)



<a name="1.0.8"></a>
## [1.0.8](https://github.com/Wikiki/bulma-tagsinput/compare/1.0.7...1.0.8) (2018-05-12)


### Bug Fixes

* [#20](https://github.com/Wikiki/bulma-tagsinput/issues/20) Deleted tags result in leading commas ([25349a1](https://github.com/Wikiki/bulma-tagsinput/commit/25349a1))



<a name="1.0.7"></a>
## [1.0.7](https://github.com/Wikiki/bulma-tagsinput/compare/1.0.6...1.0.7) (2018-03-29)



<a name="1.0.6"></a>
## [1.0.6](https://github.com/Wikiki/bulma-tagsinput/compare/1.0.1...1.0.6) (2018-02-21)



<a name="1.0.5"></a>
## [1.0.5](https://github.com/Wikiki/bulma-tagsinput/compare/1.0.1...1.0.5) (2018-02-21)



<a name="1.0.4"></a>
## [1.0.4](https://github.com/Wikiki/bulma-tagsinput/compare/1.0.3...1.0.4) (2018-02-21)



<a name="1.0.3"></a>
## [1.0.3](https://github.com/Wikiki/bulma-tagsinput/compare/1.0.2...1.0.3) (2018-02-21)



<a name="1.0.2"></a>
## [1.0.2](https://github.com/Wikiki/bulma-tagsinput/compare/1.0.1...1.0.2) (2018-02-20)



<a name="1.0.1"></a>
## [1.0.1](https://github.com/Wikiki/bulma-tagsinput/compare/1.0.0...1.0.1) (2018-02-11)


### Bug Fixes

* **gulp:** Remove Bulma’s important from dist’sass ([5bb6c9c](https://github.com/Wikiki/bulma-tagsinput/commit/5bb6c9c))



<a name="1.0.0"></a>
# [1.0.0](https://github.com/Wikiki/bulma-tagsinput/compare/0.2.7...1.0.0) (2018-02-10)


### Features

* **rollup:** Add Rollup transpilation ([548c633](https://github.com/Wikiki/bulma-tagsinput/commit/548c633))



<a name="0.2.7"></a>
## [0.2.7](https://github.com/Wikiki/bulma-tagsinput/compare/0.2.6...0.2.7) (2018-02-10)



<a name="0.2.6"></a>
## [0.2.6](https://github.com/Wikiki/bulma-tagsinput/compare/0.2.5...0.2.6) (2018-02-10)


### Bug Fixes

* **gulp:** Use UMD modules style ([3b5c8e6](https://github.com/Wikiki/bulma-tagsinput/commit/3b5c8e6))



<a name="0.2.5"></a>
## [0.2.5](https://github.com/Wikiki/bulma-tagsinput/compare/0.2.4...0.2.5) (2018-02-10)


### Bug Fixes

* **gulp:** Correct dist filenames ([60770e9](https://github.com/Wikiki/bulma-tagsinput/commit/60770e9))
* **package.json:** File paths ([71d2b72](https://github.com/Wikiki/bulma-tagsinput/commit/71d2b72))



<a name="0.2.4"></a>
## [0.2.4](https://github.com/Wikiki/bulma-tagsinput/compare/0.2.3...0.2.4) (2018-02-09)



<a name="0.2.3"></a>
## [0.2.3](https://github.com/Wikiki/bulma-tagsinput/compare/0.1.3...0.2.3) (2018-02-09)


### Bug Fixes

* **bower:** Add missing version ([cbe926e](https://github.com/Wikiki/bulma-tagsinput/commit/cbe926e))


### Features

* **gulp:** Add gulp dependencies ([c2d9f29](https://github.com/Wikiki/bulma-tagsinput/commit/c2d9f29))
* **gulp:** Add release task ([54eb049](https://github.com/Wikiki/bulma-tagsinput/commit/54eb049))



# Change Log

## [Unreleased](https://github.com/wikiki/bulma-tagsinput/tree/HEAD)

[Full Changelog](https://github.com/wikiki/bulma-tagsinput/compare/0.1.3...HEAD)

**Fixed bugs:**

- Tag selection by backspace key for empty input line not working \(Chrome\) [\#11](https://github.com/Wikiki/bulma-tagsinput/issues/11)
- Form field isn't accentuated if focused \(Bulma 0.6.1\) [\#10](https://github.com/Wikiki/bulma-tagsinput/issues/10)
- Selected tag isn't highlighted [\#8](https://github.com/Wikiki/bulma-tagsinput/issues/8)
- Tag selecting of key events is not working properly [\#7](https://github.com/Wikiki/bulma-tagsinput/issues/7)
- Selecting and deleting tags via keys not working in Chrome [\#6](https://github.com/Wikiki/bulma-tagsinput/issues/6)
- doesn't able to delete tag [\#4](https://github.com/Wikiki/bulma-tagsinput/issues/4)
- Can't create a tag with comma [\#3](https://github.com/Wikiki/bulma-tagsinput/issues/3)
- Can't delete tags with backspace key [\#2](https://github.com/Wikiki/bulma-tagsinput/issues/2)
- Update tagsinput.js [\#5](https://github.com/Wikiki/bulma-tagsinput/pull/5) ([nille](https://github.com/nille))

## [0.1.3](https://github.com/wikiki/bulma-tagsinput/tree/0.1.3) (2017-11-30)
**Merged pull requests:**

- Create LICENSE [\#1](https://github.com/Wikiki/bulma-tagsinput/pull/1) ([Wikiki](https://github.com/Wikiki))



\* *This Change Log was automatically generated by [github_changelog_generator](https://github.com/skywinder/Github-Changelog-Generator)*
